<p align="center">
  <a href="https://py-contributors.github.io/audiobook/"><img src="https://capsule-render.vercel.app/api?type=rect&color=009ACD&height=100&section=header&text=Sanatio&fontSize=80%&fontColor=ffffff" alt="website title image"></a>
  <h3 align="center">👉 Sanatio is a latin word which mean Validation 👈</h2>
  <h3 align="center"><b>Document, String, Number, Date, Email, Username, Password</b> Validator for Python. Inspired by <a href="https://github.com/validatorjs/validator.js">Validator.JS</a></h2>
</p>


## Installation

```bash
pip install sanatio
```

## Documentation

Check out the [documentation](https://sanatio.readthedocs.io/en/latest/) for more information.

## Roadmap

Check out the [roadmap](/ROADMAP.MD) for more information.

## Contributing

Check out the [contributing](/CONTRIBUTING.md) for more information.

## License

[Apache License 2.0](/LICENSE)


## Code of Conduct

[Code of Conduct](/CODE_OF_CONDUCT.md)
